In questa pagina

zabbix_sender

ZABBIX_SENDER(1)            Manuale dei comandi generali           ZABBIX_SENDER(1)

NOME
       zabbix_sender - utilità sender di Zabbix

SINTASSI
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host -k key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect cert --tls-ca-file CA-file [--tls-crl-file CRL-file]
       [--tls-server-cert-issuer cert-issuer] [--tls-server-cert-subject
       cert-subject] --tls-cert-file cert-file --tls-key-file key-file
       [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k key -o
       value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect cert --tls-ca-file CA-file [--tls-crl-file
       CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k
       key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string]
       [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender -h
       zabbix_sender -V

DESCRIZIONE
       zabbix_sender è un'utilità da riga di comando per l'invio di dati di
       monitoraggio al server o al proxy Zabbix. Sul server Zabbix deve essere
       creato un item di tipo Zabbix trapper con la chiave corrispondente. I
       valori in ingresso verranno accettati solo dagli host specificati nel
       campo Allowed hosts di questo item.

OPZIONI
       -c, --config config-file
              Utilizza config-file. Zabbix sender legge i dettagli del server
              dal file di configurazione di agentd. Per impostazione predefinita
              Zabbix sender non legge alcun file di configurazione. Sono
              supportati solo i parametri Hostname, ServerActive, SourceIP,
              TLSConnect, TLSCAFile, TLSCRLFile, TLSServerCertIssuer,
              TLSServerCertSubject, TLSCertFile, TLSKeyFile, TLSPSKIdentity e
              TLSPSKFile. L'Hostname definito tramite il parametro HostnameItem
              non verrà utilizzato; in questo caso il nome host deve essere
              specificato tramite la riga di comando (vedere l'opzione -s).
              Per l'invio dei dati vengono utilizzati tutti gli indirizzi
              definiti nel parametro di configurazione ServerActive dell'agent.
              Se l'invio di un batch di dati a un indirizzo non riesce, i batch
              successivi non vengono inviati a tale indirizzo.

       -z, --zabbix-server server
              Nome host o indirizzo IP del server Zabbix. Se un host è
              monitorato da un proxy, è necessario utilizzare il nome host o
              l'indirizzo IP del proxy. Se utilizzato insieme a --config,
              sostituisce le voci del parametro ServerActive specificate nel
              file di configurazione di agentd.

       -p, --port port
              Specifica il numero di porta su cui è in esecuzione il trapper
              del server Zabbix. Il valore predefinito è 10051. Se utilizzato
              insieme a --config, sostituisce le voci della porta del parametro
              ServerActive specificate nel file di configurazione di agentd.

       -I, --source-address IP-address
              Specifica l'indirizzo IP di origine. Se utilizzato insieme a
              --config, sostituisce il parametro SourceIP specificato nel file
              di configurazione di agentd.

       -t, --timeout seconds
              Specifica il timeout. Intervallo valido: 1-300 secondi
              (predefinito: 60)

       -s, --host host
              Specifica il nome host a cui appartiene l'item (come registrato
              nel frontend di Zabbix). L'indirizzo IP e il nome DNS dell'host
              non funzioneranno. Se utilizzato insieme a --config, sostituisce
              il parametro Hostname specificato nel file di configurazione di
              agentd.

       -k, --key key
              Specifica la chiave dell'item a cui inviare il valore.

       -o, --value value
              Specifica il valore dell'item.

       -i, --input-file input-file
              Carica i valori dal file di input. Specificare - come
              <input-file> per leggere i valori dallo standard input. Ogni
              riga del file contiene, separati da spazi bianchi:
              <hostname> <key> <value>. Ogni valore deve essere specificato
              nella propria riga. Ogni riga deve contenere 3 elementi separati
              da spazi bianchi: <hostname> <key> <value>, dove "hostname" è il
              nome dell'host monitorato come registrato nel frontend di Zabbix,
              "key" è la chiave dell'item di destinazione e "value" è il valore
              da inviare. Specificare - come <hostname> per utilizzare il nome
              host dal file di configurazione dell'agent o dall'argomento
              --host.

              Esempio di una riga di un file di input:

               "Linux DB3" db.connections 43

              Il tipo di valore deve essere impostato correttamente nella
              configurazione dell'item del frontend di Zabbix. Zabbix sender
              invia fino a 250 valori in una connessione. Il contenuto del
              file di input deve essere codificato in UTF-8. Tutti i valori del
              file di input vengono inviati in ordine sequenziale, dall'alto
              verso il basso. Le voci devono essere formattate secondo le
              seguenti regole:

                     • Sono supportate voci tra virgolette e non tra virgolette.

                     • Il carattere virgolette doppie è il carattere di
                       delimitazione.

                     • Le voci contenenti spazi bianchi devono essere racchiuse
                       tra virgolette.

                     • I caratteri virgolette doppie e barra rovesciata
                       all'interno di una voce tra virgolette devono essere
                       preceduti da una barra rovesciata.

                     • L'escape non è supportato nelle voci non racchiuse tra
                       virgolette.

                     • Le sequenze di escape per il ritorno a capo (\n) sono
                       supportate nelle stringhe tra virgolette.

                     • Le sequenze di escape per il ritorno a capo vengono
                       rimosse dalla fine di una voce.

       -T, --with-timestamps
              Questa opzione può essere utilizzata solo con l'opzione
              --input-file.

              Ogni riga del file di input deve contenere 4 elementi separati da
              spazi bianchi: <hostname> <key> <timestamp> <value>. Il timestamp
              deve essere specificato nel formato Unix timestamp. Se l'item di
              destinazione ha trigger che fanno riferimento a esso, tutti i
              timestamp devono essere in ordine crescente; in caso contrario, il
              calcolo dell'evento non sarà corretto.

              Esempio di una riga di un file di input:

               "Linux DB3" db.connections 1429533600 43

              Per ulteriori dettagli, vedere l'opzione --input-file.

              Se viene inviato un valore con timestamp per un host che si trova
              in un periodo di manutenzione di tipo “no data”, il valore verrà
              eliminato; tuttavia, è possibile inviare un valore con timestamp
              relativo a un periodo di manutenzione scaduto e il valore verrà
              accettato.

       -N, --with-ns
              Questa opzione può essere utilizzata solo con l'opzione
              --with-timestamps.

              Ogni riga del file di input deve contenere 5 elementi separati da
              spazi bianchi: <hostname> <key> <timestamp> <ns> <value>.

              Esempio di una riga di un file di input:

               "Linux DB3" db.connections 1429533600 7402561 43

              Per ulteriori dettagli, vedere l'opzione --input-file.

       -r, --real-time
              Invia i valori uno alla volta non appena vengono ricevuti. Può
              essere utilizzato durante la lettura dallo standard input.

       --tls-connect value
              Come connettersi al server o al proxy. Valori:

                   unencrypted
                               connessione senza crittografia (predefinito)

                   psk         connessione tramite TLS e una chiave
                               precondivisa

                   cert        connessione tramite TLS e un certificato

       --tls-ca-file CA-file
              Percorso completo di un file contenente i certificati CA di
              livello superiore per la verifica del certificato del peer.

       --tls-crl-file CRL-file
              Percorso completo di un file contenente i certificati revocati.

       --tls-server-cert-issuer cert-issuer
              Emittente del certificato del server consentito.

       --tls-server-cert-subject cert-subject
              Subject del certificato del server consentito.

       --tls-cert-file cert-file
              Percorso completo di un file contenente il certificato o la
              catena di certificati.

       --tls-key-file key-file
              Percorso completo di un file contenente la chiave privata.

       --tls-psk-identity PSK-identity
              Stringa dell'identità PSK.

       --tls-psk-file PSK-file
              Percorso completo di un file contenente la chiave precondivisa.

       --tls-cipher13 cipher-string
              Stringa di cifratura per OpenSSL 1.1.1 o versioni successive per
              TLS 1.3. Sostituisce i criteri predefiniti di selezione della
              suite di cifratura. Questa opzione non è disponibile se la
              versione di OpenSSL è precedente alla 1.1.1.

       --tls-cipher cipher-string
              Stringa di priorità GnuTLS (per TLS 1.2 e versioni successive) o
              stringa di cifratura OpenSSL (solo per TLS 1.2). Sostituisce i
              criteri predefiniti di selezione della suite di cifratura.

       -v, --verbose
              Modalità dettagliata; utilizzare -vv per ulteriori dettagli.

       -h, --help
              Visualizza questo messaggio di aiuto ed esce.

       -V, --version
              Visualizza le informazioni sulla versione ed esce.

STATO DI USCITA
       Lo stato di uscita è 0 se i valori sono stati inviati e tutti sono stati
       elaborati correttamente dal server. Se i dati sono stati inviati, ma
       l'elaborazione di almeno uno dei valori non è riuscita, lo stato di
       uscita è 2. Se l'invio dei dati non è riuscito, lo stato di uscita è 1.

ESEMPI
       zabbix_sender -c  /etc/zabbix/zabbix_agentd.conf  -k  mysql.queries  -o
       342.45
              Invia 342.45 come valore dell'item mysql.queries dell'host
              monitorato. Utilizza l'host monitorato e il server Zabbix definiti
              nel file di configurazione dell'agent.

       zabbix_sender -c /etc/zabbix/zabbix_agentd.conf -s "Monitored Host"  -k
       mysql.queries -o 342.45
              Invia 342.45 come valore dell'item mysql.queries dell'host
              Monitored Host utilizzando il server Zabbix definito nel file di
              configurazione dell'agent.

       zabbix_sender -z 192.168.1.113 -i data_values.txt
              Invia i valori dal file data_values.txt al server Zabbix con
              indirizzo IP 192.168.1.113. I nomi host e le chiavi sono definiti
              nel file.

       echo "- hw.serial.number  1287872261  SQ4321ASDF"  |  zabbix_sender  -c
       /usr/local/etc/zabbix_agentd.conf -T -i -
              Invia un valore con timestamp dalla riga di comando al server
              Zabbix specificato nel file di configurazione dell'agent. Il
              trattino nei dati di input indica che anche il nome host deve
              essere utilizzato dallo stesso file di configurazione.

       echo '"Zabbix server" trapper.item ""' | zabbix_sender -z 192.168.1.113
       -p 10000 -i -
              Invia un valore vuoto di un item al server Zabbix con indirizzo IP
              192.168.1.113 sulla porta 10000 dalla riga di comando. I valori
              vuoti devono essere indicati da virgolette doppie vuote.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  cert  --tls-ca-file  /home/zabbix/zabbix_ca_file
       --tls-cert-file      /home/zabbix/zabbix_agentd.crt      --tls-key-file
       /home/zabbix/zabbix_agentd.key
              Invia 342.45 come valore dell'item mysql.queries dell'host
              Monitored Host al server con indirizzo IP 192.168.1.113
              utilizzando TLS con un certificato.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  psk  --tls-psk-identity  "PSK  ID Zabbix agentd"
       --tls-psk-file /home/zabbix/zabbix_agentd.psk
              Invia 342.45 come valore dell'item mysql.queries dell'host
              Monitored Host al server con indirizzo IP 192.168.1.113
              utilizzando TLS con una chiave precondivisa (PSK).

VEDERE ANCHE
       Documentazione

       zabbix_agentd(8),  zabbix_get(1),  zabbix_proxy(8),   zabbix_server(8),
       zabbix_js(1), zabbix_agent2(8), zabbix_web_service(8)

Zabbix                            2022-01-06                  ZABBIX_SENDER(1)